Enum westend_runtime::EPMCall [−][src]
pub enum EPMCall<T> where
T: Config, {
submit_unsigned {
raw_solution: Box<RawSolution<<T as Config>::Solution>, Global>,
witness: SolutionOrSnapshotSize,
},
set_minimum_untrusted_score {
maybe_next_score: Option<[u128; 3]>,
},
set_emergency_election_result {
supports: Vec<(<T as Config>::AccountId, Support<<T as Config>::AccountId>), Global>,
},
submit {
raw_solution: Box<RawSolution<<T as Config>::Solution>, Global>,
num_signed_submissions: u32,
},
// some variants omitted
}Expand description
Contains one variant per dispatchable that can be called by an extrinsic.
Variants
Submit a solution for the unsigned phase.
The dispatch origin fo this call must be none.
This submission is checked on the fly. Moreover, this unsigned solution is only validated when submitted to the pool from the local node. Effectively, this means that only active validators can submit this transaction when authoring a block (similar to an inherent).
To prevent any incorrect solution (and thus wasted time/weight), this transaction will panic if the solution submitted by the validator is invalid in any way, effectively putting their authoring reward at risk.
No deposit or reward is associated with this submission.
Fields of submit_unsigned
raw_solution: Box<RawSolution<<T as Config>::Solution>, Global>witness: SolutionOrSnapshotSizeSet a new value for MinimumUntrustedScore.
Dispatch origin must be aligned with T::ForceOrigin.
This check can be turned off by setting the value to None.
Set a solution in the queue, to be handed out to the client of this pallet in the next
call to ElectionProvider::elect.
This can only be set by T::ForceOrigin, and only when the phase is Emergency.
The solution is not checked for any feasibility and is assumed to be trustworthy, as any feasibility check itself can in principle cause the election process to fail (due to memory/weight constrains).
Fields of set_emergency_election_result
Submit a solution for the signed phase.
The dispatch origin fo this call must be signed.
The solution is potentially queued, based on the claimed score and processed at the end of the signed phase.
A deposit is reserved and recorded for the solution. Based on the outcome, the solution might be rewarded, slashed, or get all or a part of the deposit back.
Queue size must be provided as witness data.
Fields of submit
Implementations
pub fn new_call_variant_submit_unsigned(
raw_solution: Box<RawSolution<<T as Config>::Solution>, Global>,
witness: SolutionOrSnapshotSize
) -> Call<T>
pub fn new_call_variant_submit_unsigned(
raw_solution: Box<RawSolution<<T as Config>::Solution>, Global>,
witness: SolutionOrSnapshotSize
) -> Call<T>
Create a call with the variant submit_unsigned.
Create a call with the variant set_minimum_untrusted_score.
Create a call with the variant set_emergency_election_result.
pub fn new_call_variant_submit(
raw_solution: Box<RawSolution<<T as Config>::Solution>, Global>,
num_signed_submissions: u32
) -> Call<T>
pub fn new_call_variant_submit(
raw_solution: Box<RawSolution<<T as Config>::Solution>, Global>,
num_signed_submissions: u32
) -> Call<T>
Create a call with the variant submit.